@@ -98,36 +98,39 @@ __all__ = (
 ArtworkTypeDef = TypedDict(
     "ArtworkTypeDef",
     {
-        "InputKey": NotRequired[str],
-        "MaxWidth": NotRequired[str],
-        "MaxHeight": NotRequired[str],
-        "SizingPolicy": NotRequired[str],
-        "PaddingPolicy": NotRequired[str],
-        "AlbumArtFormat": NotRequired[str],
-        "Encryption": NotRequired["EncryptionTypeDef"],
+        "InputKey": str,
+        "MaxWidth": str,
+        "MaxHeight": str,
+        "SizingPolicy": str,
+        "PaddingPolicy": str,
+        "AlbumArtFormat": str,
+        "Encryption": "EncryptionTypeDef",
     },
+    total=False,
 )
 
 AudioCodecOptionsTypeDef = TypedDict(
     "AudioCodecOptionsTypeDef",
     {
-        "Profile": NotRequired[str],
-        "BitDepth": NotRequired[str],
-        "BitOrder": NotRequired[str],
-        "Signed": NotRequired[str],
+        "Profile": str,
+        "BitDepth": str,
+        "BitOrder": str,
+        "Signed": str,
     },
+    total=False,
 )
 
 AudioParametersTypeDef = TypedDict(
     "AudioParametersTypeDef",
     {
-        "Codec": NotRequired[str],
-        "SampleRate": NotRequired[str],
-        "BitRate": NotRequired[str],
-        "Channels": NotRequired[str],
-        "AudioPackingMode": NotRequired[str],
-        "CodecOptions": NotRequired["AudioCodecOptionsTypeDef"],
+        "Codec": str,
+        "SampleRate": str,
+        "BitRate": str,
+        "Channels": str,
+        "AudioPackingMode": str,
+        "CodecOptions": "AudioCodecOptionsTypeDef",
     },
+    total=False,
 )
 
 CancelJobRequestRequestTypeDef = TypedDict(
@@ -140,80 +143,99 @@ CancelJobRequestRequestTypeDef = TypedDict(
 CaptionFormatTypeDef = TypedDict(
     "CaptionFormatTypeDef",
     {
-        "Format": NotRequired[str],
-        "Pattern": NotRequired[str],
-        "Encryption": NotRequired["EncryptionTypeDef"],
+        "Format": str,
+        "Pattern": str,
+        "Encryption": "EncryptionTypeDef",
     },
+    total=False,
 )
 
 CaptionSourceTypeDef = TypedDict(
     "CaptionSourceTypeDef",
     {
-        "Key": NotRequired[str],
-        "Language": NotRequired[str],
-        "TimeOffset": NotRequired[str],
-        "Label": NotRequired[str],
-        "Encryption": NotRequired["EncryptionTypeDef"],
+        "Key": str,
+        "Language": str,
+        "TimeOffset": str,
+        "Label": str,
+        "Encryption": "EncryptionTypeDef",
     },
+    total=False,
 )
 
 CaptionsTypeDef = TypedDict(
     "CaptionsTypeDef",
     {
-        "MergePolicy": NotRequired[str],
-        "CaptionSources": NotRequired[Sequence["CaptionSourceTypeDef"]],
-        "CaptionFormats": NotRequired[Sequence["CaptionFormatTypeDef"]],
+        "MergePolicy": str,
+        "CaptionSources": Sequence["CaptionSourceTypeDef"],
+        "CaptionFormats": Sequence["CaptionFormatTypeDef"],
     },
+    total=False,
 )
 
 ClipTypeDef = TypedDict(
     "ClipTypeDef",
     {
-        "TimeSpan": NotRequired["TimeSpanTypeDef"],
+        "TimeSpan": "TimeSpanTypeDef",
     },
+    total=False,
 )
 
 CreateJobOutputTypeDef = TypedDict(
     "CreateJobOutputTypeDef",
     {
-        "Key": NotRequired[str],
-        "ThumbnailPattern": NotRequired[str],
-        "ThumbnailEncryption": NotRequired["EncryptionTypeDef"],
-        "Rotate": NotRequired[str],
-        "PresetId": NotRequired[str],
-        "SegmentDuration": NotRequired[str],
-        "Watermarks": NotRequired[Sequence["JobWatermarkTypeDef"]],
-        "AlbumArt": NotRequired["JobAlbumArtTypeDef"],
-        "Composition": NotRequired[Sequence["ClipTypeDef"]],
-        "Captions": NotRequired["CaptionsTypeDef"],
-        "Encryption": NotRequired["EncryptionTypeDef"],
+        "Key": str,
+        "ThumbnailPattern": str,
+        "ThumbnailEncryption": "EncryptionTypeDef",
+        "Rotate": str,
+        "PresetId": str,
+        "SegmentDuration": str,
+        "Watermarks": Sequence["JobWatermarkTypeDef"],
+        "AlbumArt": "JobAlbumArtTypeDef",
+        "Composition": Sequence["ClipTypeDef"],
+        "Captions": "CaptionsTypeDef",
+        "Encryption": "EncryptionTypeDef",
     },
+    total=False,
 )
 
 CreateJobPlaylistTypeDef = TypedDict(
     "CreateJobPlaylistTypeDef",
     {
-        "Name": NotRequired[str],
-        "Format": NotRequired[str],
-        "OutputKeys": NotRequired[Sequence[str]],
-        "HlsContentProtection": NotRequired["HlsContentProtectionTypeDef"],
-        "PlayReadyDrm": NotRequired["PlayReadyDrmTypeDef"],
+        "Name": str,
+        "Format": str,
+        "OutputKeys": Sequence[str],
+        "HlsContentProtection": "HlsContentProtectionTypeDef",
+        "PlayReadyDrm": "PlayReadyDrmTypeDef",
     },
+    total=False,
 )
 
-CreateJobRequestRequestTypeDef = TypedDict(
-    "CreateJobRequestRequestTypeDef",
+_RequiredCreateJobRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateJobRequestRequestTypeDef",
     {
         "PipelineId": str,
-        "Input": NotRequired["JobInputTypeDef"],
-        "Inputs": NotRequired[Sequence["JobInputTypeDef"]],
-        "Output": NotRequired["CreateJobOutputTypeDef"],
-        "Outputs": NotRequired[Sequence["CreateJobOutputTypeDef"]],
-        "OutputKeyPrefix": NotRequired[str],
-        "Playlists": NotRequired[Sequence["CreateJobPlaylistTypeDef"]],
-        "UserMetadata": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateJobRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateJobRequestRequestTypeDef",
+    {
+        "Input": "JobInputTypeDef",
+        "Inputs": Sequence["JobInputTypeDef"],
+        "Output": "CreateJobOutputTypeDef",
+        "Outputs": Sequence["CreateJobOutputTypeDef"],
+        "OutputKeyPrefix": str,
+        "Playlists": Sequence["CreateJobPlaylistTypeDef"],
+        "UserMetadata": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateJobRequestRequestTypeDef(
+    _RequiredCreateJobRequestRequestTypeDef, _OptionalCreateJobRequestRequestTypeDef
+):
+    pass
+
 
 CreateJobResponseTypeDef = TypedDict(
     "CreateJobResponseTypeDef",
@@ -223,19 +245,32 @@ CreateJobResponseTypeDef = TypedDict(
     },
 )
 
-CreatePipelineRequestRequestTypeDef = TypedDict(
-    "CreatePipelineRequestRequestTypeDef",
+_RequiredCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineRequestRequestTypeDef",
     {
         "Name": str,
         "InputBucket": str,
         "Role": str,
-        "OutputBucket": NotRequired[str],
-        "AwsKmsKeyArn": NotRequired[str],
-        "Notifications": NotRequired["NotificationsTypeDef"],
-        "ContentConfig": NotRequired["PipelineOutputConfigTypeDef"],
-        "ThumbnailConfig": NotRequired["PipelineOutputConfigTypeDef"],
     },
 )
+_OptionalCreatePipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineRequestRequestTypeDef",
+    {
+        "OutputBucket": str,
+        "AwsKmsKeyArn": str,
+        "Notifications": "NotificationsTypeDef",
+        "ContentConfig": "PipelineOutputConfigTypeDef",
+        "ThumbnailConfig": "PipelineOutputConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class CreatePipelineRequestRequestTypeDef(
+    _RequiredCreatePipelineRequestRequestTypeDef, _OptionalCreatePipelineRequestRequestTypeDef
+):
+    pass
+
 
 CreatePipelineResponseTypeDef = TypedDict(
     "CreatePipelineResponseTypeDef",
@@ -246,17 +281,30 @@ CreatePipelineResponseTypeDef = TypedDict(
     },
 )
 
-CreatePresetRequestRequestTypeDef = TypedDict(
-    "CreatePresetRequestRequestTypeDef",
+_RequiredCreatePresetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreatePresetRequestRequestTypeDef",
     {
         "Name": str,
         "Container": str,
-        "Description": NotRequired[str],
-        "Video": NotRequired["VideoParametersTypeDef"],
-        "Audio": NotRequired["AudioParametersTypeDef"],
-        "Thumbnails": NotRequired["ThumbnailsTypeDef"],
     },
 )
+_OptionalCreatePresetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreatePresetRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Video": "VideoParametersTypeDef",
+        "Audio": "AudioParametersTypeDef",
+        "Thumbnails": "ThumbnailsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreatePresetRequestRequestTypeDef(
+    _RequiredCreatePresetRequestRequestTypeDef, _OptionalCreatePresetRequestRequestTypeDef
+):
+    pass
+
 
 CreatePresetResponseTypeDef = TypedDict(
     "CreatePresetResponseTypeDef",
@@ -284,139 +332,176 @@ DeletePresetRequestRequestTypeDef = TypedDict(
 DetectedPropertiesTypeDef = TypedDict(
     "DetectedPropertiesTypeDef",
     {
-        "Width": NotRequired[int],
-        "Height": NotRequired[int],
-        "FrameRate": NotRequired[str],
-        "FileSize": NotRequired[int],
-        "DurationMillis": NotRequired[int],
+        "Width": int,
+        "Height": int,
+        "FrameRate": str,
+        "FileSize": int,
+        "DurationMillis": int,
     },
+    total=False,
 )
 
 EncryptionTypeDef = TypedDict(
     "EncryptionTypeDef",
     {
-        "Mode": NotRequired[str],
-        "Key": NotRequired[str],
-        "KeyMd5": NotRequired[str],
-        "InitializationVector": NotRequired[str],
+        "Mode": str,
+        "Key": str,
+        "KeyMd5": str,
+        "InitializationVector": str,
     },
+    total=False,
 )
 
 HlsContentProtectionTypeDef = TypedDict(
     "HlsContentProtectionTypeDef",
     {
-        "Method": NotRequired[str],
-        "Key": NotRequired[str],
-        "KeyMd5": NotRequired[str],
-        "InitializationVector": NotRequired[str],
-        "LicenseAcquisitionUrl": NotRequired[str],
-        "KeyStoragePolicy": NotRequired[str],
+        "Method": str,
+        "Key": str,
+        "KeyMd5": str,
+        "InitializationVector": str,
+        "LicenseAcquisitionUrl": str,
+        "KeyStoragePolicy": str,
     },
+    total=False,
 )
 
 InputCaptionsTypeDef = TypedDict(
     "InputCaptionsTypeDef",
     {
-        "MergePolicy": NotRequired[str],
-        "CaptionSources": NotRequired[Sequence["CaptionSourceTypeDef"]],
+        "MergePolicy": str,
+        "CaptionSources": Sequence["CaptionSourceTypeDef"],
     },
+    total=False,
 )
 
 JobAlbumArtTypeDef = TypedDict(
     "JobAlbumArtTypeDef",
     {
-        "MergePolicy": NotRequired[str],
-        "Artwork": NotRequired[Sequence["ArtworkTypeDef"]],
+        "MergePolicy": str,
+        "Artwork": Sequence["ArtworkTypeDef"],
     },
+    total=False,
 )
 
 JobInputTypeDef = TypedDict(
     "JobInputTypeDef",
     {
-        "Key": NotRequired[str],
-        "FrameRate": NotRequired[str],
-        "Resolution": NotRequired[str],
-        "AspectRatio": NotRequired[str],
-        "Interlaced": NotRequired[str],
-        "Container": NotRequired[str],
-        "Encryption": NotRequired["EncryptionTypeDef"],
-        "TimeSpan": NotRequired["TimeSpanTypeDef"],
-        "InputCaptions": NotRequired["InputCaptionsTypeDef"],
-        "DetectedProperties": NotRequired["DetectedPropertiesTypeDef"],
+        "Key": str,
+        "FrameRate": str,
+        "Resolution": str,
+        "AspectRatio": str,
+        "Interlaced": str,
+        "Container": str,
+        "Encryption": "EncryptionTypeDef",
+        "TimeSpan": "TimeSpanTypeDef",
+        "InputCaptions": "InputCaptionsTypeDef",
+        "DetectedProperties": "DetectedPropertiesTypeDef",
     },
+    total=False,
 )
 
 JobOutputTypeDef = TypedDict(
     "JobOutputTypeDef",
     {
-        "Id": NotRequired[str],
-        "Key": NotRequired[str],
-        "ThumbnailPattern": NotRequired[str],
-        "ThumbnailEncryption": NotRequired["EncryptionTypeDef"],
-        "Rotate": NotRequired[str],
-        "PresetId": NotRequired[str],
-        "SegmentDuration": NotRequired[str],
-        "Status": NotRequired[str],
-        "StatusDetail": NotRequired[str],
-        "Duration": NotRequired[int],
-        "Width": NotRequired[int],
-        "Height": NotRequired[int],
-        "FrameRate": NotRequired[str],
-        "FileSize": NotRequired[int],
-        "DurationMillis": NotRequired[int],
-        "Watermarks": NotRequired[List["JobWatermarkTypeDef"]],
-        "AlbumArt": NotRequired["JobAlbumArtTypeDef"],
-        "Composition": NotRequired[List["ClipTypeDef"]],
-        "Captions": NotRequired["CaptionsTypeDef"],
-        "Encryption": NotRequired["EncryptionTypeDef"],
-        "AppliedColorSpaceConversion": NotRequired[str],
+        "Id": str,
+        "Key": str,
+        "ThumbnailPattern": str,
+        "ThumbnailEncryption": "EncryptionTypeDef",
+        "Rotate": str,
+        "PresetId": str,
+        "SegmentDuration": str,
+        "Status": str,
+        "StatusDetail": str,
+        "Duration": int,
+        "Width": int,
+        "Height": int,
+        "FrameRate": str,
+        "FileSize": int,
+        "DurationMillis": int,
+        "Watermarks": List["JobWatermarkTypeDef"],
+        "AlbumArt": "JobAlbumArtTypeDef",
+        "Composition": List["ClipTypeDef"],
+        "Captions": "CaptionsTypeDef",
+        "Encryption": "EncryptionTypeDef",
+        "AppliedColorSpaceConversion": str,
     },
+    total=False,
 )
 
 JobTypeDef = TypedDict(
     "JobTypeDef",
     {
-        "Id": NotRequired[str],
-        "Arn": NotRequired[str],
-        "PipelineId": NotRequired[str],
-        "Input": NotRequired["JobInputTypeDef"],
-        "Inputs": NotRequired[List["JobInputTypeDef"]],
-        "Output": NotRequired["JobOutputTypeDef"],
-        "Outputs": NotRequired[List["JobOutputTypeDef"]],
-        "OutputKeyPrefix": NotRequired[str],
-        "Playlists": NotRequired[List["PlaylistTypeDef"]],
-        "Status": NotRequired[str],
-        "UserMetadata": NotRequired[Dict[str, str]],
-        "Timing": NotRequired["TimingTypeDef"],
+        "Id": str,
+        "Arn": str,
+        "PipelineId": str,
+        "Input": "JobInputTypeDef",
+        "Inputs": List["JobInputTypeDef"],
+        "Output": "JobOutputTypeDef",
+        "Outputs": List["JobOutputTypeDef"],
+        "OutputKeyPrefix": str,
+        "Playlists": List["PlaylistTypeDef"],
+        "Status": str,
+        "UserMetadata": Dict[str, str],
+        "Timing": "TimingTypeDef",
     },
+    total=False,
 )
 
 JobWatermarkTypeDef = TypedDict(
     "JobWatermarkTypeDef",
     {
-        "PresetWatermarkId": NotRequired[str],
-        "InputKey": NotRequired[str],
-        "Encryption": NotRequired["EncryptionTypeDef"],
+        "PresetWatermarkId": str,
+        "InputKey": str,
+        "Encryption": "EncryptionTypeDef",
     },
+    total=False,
 )
 
-ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef = TypedDict(
-    "ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef",
+_RequiredListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef = TypedDict(
+    "_RequiredListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef",
     {
         "PipelineId": str,
-        "Ascending": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef = TypedDict(
+    "_OptionalListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef",
+    {
+        "Ascending": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListJobsByPipelineRequestRequestTypeDef = TypedDict(
-    "ListJobsByPipelineRequestRequestTypeDef",
+
+class ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef(
+    _RequiredListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef,
+    _OptionalListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef,
+):
+    pass
+
+
+_RequiredListJobsByPipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobsByPipelineRequestRequestTypeDef",
     {
         "PipelineId": str,
-        "Ascending": NotRequired[str],
-        "PageToken": NotRequired[str],
     },
 )
+_OptionalListJobsByPipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobsByPipelineRequestRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
+    },
+    total=False,
+)
+
+
+class ListJobsByPipelineRequestRequestTypeDef(
+    _RequiredListJobsByPipelineRequestRequestTypeDef,
+    _OptionalListJobsByPipelineRequestRequestTypeDef,
+):
+    pass
+
 
 ListJobsByPipelineResponseTypeDef = TypedDict(
     "ListJobsByPipelineResponseTypeDef",
@@ -427,23 +512,50 @@ ListJobsByPipelineResponseTypeDef = TypedDict(
     },
 )
 
-ListJobsByStatusRequestListJobsByStatusPaginateTypeDef = TypedDict(
-    "ListJobsByStatusRequestListJobsByStatusPaginateTypeDef",
+_RequiredListJobsByStatusRequestListJobsByStatusPaginateTypeDef = TypedDict(
+    "_RequiredListJobsByStatusRequestListJobsByStatusPaginateTypeDef",
     {
         "Status": str,
-        "Ascending": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListJobsByStatusRequestListJobsByStatusPaginateTypeDef = TypedDict(
+    "_OptionalListJobsByStatusRequestListJobsByStatusPaginateTypeDef",
+    {
+        "Ascending": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListJobsByStatusRequestRequestTypeDef = TypedDict(
-    "ListJobsByStatusRequestRequestTypeDef",
+
+class ListJobsByStatusRequestListJobsByStatusPaginateTypeDef(
+    _RequiredListJobsByStatusRequestListJobsByStatusPaginateTypeDef,
+    _OptionalListJobsByStatusRequestListJobsByStatusPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListJobsByStatusRequestRequestTypeDef = TypedDict(
+    "_RequiredListJobsByStatusRequestRequestTypeDef",
     {
         "Status": str,
-        "Ascending": NotRequired[str],
-        "PageToken": NotRequired[str],
     },
 )
+_OptionalListJobsByStatusRequestRequestTypeDef = TypedDict(
+    "_OptionalListJobsByStatusRequestRequestTypeDef",
+    {
+        "Ascending": str,
+        "PageToken": str,
+    },
+    total=False,
+)
+
+
+class ListJobsByStatusRequestRequestTypeDef(
+    _RequiredListJobsByStatusRequestRequestTypeDef, _OptionalListJobsByStatusRequestRequestTypeDef
+):
+    pass
+
 
 ListJobsByStatusResponseTypeDef = TypedDict(
     "ListJobsByStatusResponseTypeDef",
@@ -457,17 +569,19 @@ ListJobsByStatusResponseTypeDef = TypedDict(
 ListPipelinesRequestListPipelinesPaginateTypeDef = TypedDict(
     "ListPipelinesRequestListPipelinesPaginateTypeDef",
     {
-        "Ascending": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "Ascending": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListPipelinesRequestRequestTypeDef = TypedDict(
     "ListPipelinesRequestRequestTypeDef",
     {
-        "Ascending": NotRequired[str],
-        "PageToken": NotRequired[str],
+        "Ascending": str,
+        "PageToken": str,
     },
+    total=False,
 )
 
 ListPipelinesResponseTypeDef = TypedDict(
@@ -482,17 +596,19 @@ ListPipelinesResponseTypeDef = TypedDict(
 ListPresetsRequestListPresetsPaginateTypeDef = TypedDict(
     "ListPresetsRequestListPresetsPaginateTypeDef",
     {
-        "Ascending": NotRequired[str],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "Ascending": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListPresetsRequestRequestTypeDef = TypedDict(
     "ListPresetsRequestRequestTypeDef",
     {
-        "Ascending": NotRequired[str],
-        "PageToken": NotRequired[str],
+        "Ascending": str,
+        "PageToken": str,
     },
+    total=False,
 )
 
 ListPresetsResponseTypeDef = TypedDict(
@@ -507,120 +623,142 @@ ListPresetsResponseTypeDef = TypedDict(
 NotificationsTypeDef = TypedDict(
     "NotificationsTypeDef",
     {
-        "Progressing": NotRequired[str],
-        "Completed": NotRequired[str],
-        "Warning": NotRequired[str],
-        "Error": NotRequired[str],
+        "Progressing": str,
+        "Completed": str,
+        "Warning": str,
+        "Error": str,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 PermissionTypeDef = TypedDict(
     "PermissionTypeDef",
     {
-        "GranteeType": NotRequired[str],
-        "Grantee": NotRequired[str],
-        "Access": NotRequired[Sequence[str]],
+        "GranteeType": str,
+        "Grantee": str,
+        "Access": Sequence[str],
     },
+    total=False,
 )
 
 PipelineOutputConfigTypeDef = TypedDict(
     "PipelineOutputConfigTypeDef",
     {
-        "Bucket": NotRequired[str],
-        "StorageClass": NotRequired[str],
-        "Permissions": NotRequired[Sequence["PermissionTypeDef"]],
+        "Bucket": str,
+        "StorageClass": str,
+        "Permissions": Sequence["PermissionTypeDef"],
     },
+    total=False,
 )
 
 PipelineTypeDef = TypedDict(
     "PipelineTypeDef",
     {
-        "Id": NotRequired[str],
-        "Arn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Status": NotRequired[str],
-        "InputBucket": NotRequired[str],
-        "OutputBucket": NotRequired[str],
-        "Role": NotRequired[str],
-        "AwsKmsKeyArn": NotRequired[str],
-        "Notifications": NotRequired["NotificationsTypeDef"],
-        "ContentConfig": NotRequired["PipelineOutputConfigTypeDef"],
-        "ThumbnailConfig": NotRequired["PipelineOutputConfigTypeDef"],
+        "Id": str,
+        "Arn": str,
+        "Name": str,
+        "Status": str,
+        "InputBucket": str,
+        "OutputBucket": str,
+        "Role": str,
+        "AwsKmsKeyArn": str,
+        "Notifications": "NotificationsTypeDef",
+        "ContentConfig": "PipelineOutputConfigTypeDef",
+        "ThumbnailConfig": "PipelineOutputConfigTypeDef",
     },
+    total=False,
 )
 
 PlayReadyDrmTypeDef = TypedDict(
     "PlayReadyDrmTypeDef",
     {
-        "Format": NotRequired[str],
-        "Key": NotRequired[str],
-        "KeyMd5": NotRequired[str],
-        "KeyId": NotRequired[str],
-        "InitializationVector": NotRequired[str],
-        "LicenseAcquisitionUrl": NotRequired[str],
+        "Format": str,
+        "Key": str,
+        "KeyMd5": str,
+        "KeyId": str,
+        "InitializationVector": str,
+        "LicenseAcquisitionUrl": str,
     },
+    total=False,
 )
 
 PlaylistTypeDef = TypedDict(
     "PlaylistTypeDef",
     {
-        "Name": NotRequired[str],
-        "Format": NotRequired[str],
-        "OutputKeys": NotRequired[List[str]],
-        "HlsContentProtection": NotRequired["HlsContentProtectionTypeDef"],
-        "PlayReadyDrm": NotRequired["PlayReadyDrmTypeDef"],
-        "Status": NotRequired[str],
-        "StatusDetail": NotRequired[str],
+        "Name": str,
+        "Format": str,
+        "OutputKeys": List[str],
+        "HlsContentProtection": "HlsContentProtectionTypeDef",
+        "PlayReadyDrm": "PlayReadyDrmTypeDef",
+        "Status": str,
+        "StatusDetail": str,
     },
+    total=False,
 )
 
 PresetTypeDef = TypedDict(
     "PresetTypeDef",
     {
-        "Id": NotRequired[str],
-        "Arn": NotRequired[str],
-        "Name": NotRequired[str],
-        "Description": NotRequired[str],
-        "Container": NotRequired[str],
-        "Audio": NotRequired["AudioParametersTypeDef"],
-        "Video": NotRequired["VideoParametersTypeDef"],
-        "Thumbnails": NotRequired["ThumbnailsTypeDef"],
-        "Type": NotRequired[str],
+        "Id": str,
+        "Arn": str,
+        "Name": str,
+        "Description": str,
+        "Container": str,
+        "Audio": "AudioParametersTypeDef",
+        "Video": "VideoParametersTypeDef",
+        "Thumbnails": "ThumbnailsTypeDef",
+        "Type": str,
     },
+    total=False,
 )
 
 PresetWatermarkTypeDef = TypedDict(
     "PresetWatermarkTypeDef",
     {
-        "Id": NotRequired[str],
-        "MaxWidth": NotRequired[str],
-        "MaxHeight": NotRequired[str],
-        "SizingPolicy": NotRequired[str],
-        "HorizontalAlign": NotRequired[str],
-        "HorizontalOffset": NotRequired[str],
-        "VerticalAlign": NotRequired[str],
-        "VerticalOffset": NotRequired[str],
-        "Opacity": NotRequired[str],
-        "Target": NotRequired[str],
+        "Id": str,
+        "MaxWidth": str,
+        "MaxHeight": str,
+        "SizingPolicy": str,
+        "HorizontalAlign": str,
+        "HorizontalOffset": str,
+        "VerticalAlign": str,
+        "VerticalOffset": str,
+        "Opacity": str,
+        "Target": str,
     },
+    total=False,
 )
 
-ReadJobRequestJobCompleteWaitTypeDef = TypedDict(
-    "ReadJobRequestJobCompleteWaitTypeDef",
+_RequiredReadJobRequestJobCompleteWaitTypeDef = TypedDict(
+    "_RequiredReadJobRequestJobCompleteWaitTypeDef",
     {
         "Id": str,
-        "WaiterConfig": NotRequired["WaiterConfigTypeDef"],
     },
 )
+_OptionalReadJobRequestJobCompleteWaitTypeDef = TypedDict(
+    "_OptionalReadJobRequestJobCompleteWaitTypeDef",
+    {
+        "WaiterConfig": "WaiterConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ReadJobRequestJobCompleteWaitTypeDef(
+    _RequiredReadJobRequestJobCompleteWaitTypeDef, _OptionalReadJobRequestJobCompleteWaitTypeDef
+):
+    pass
+
 
 ReadJobRequestRequestTypeDef = TypedDict(
     "ReadJobRequestRequestTypeDef",
@@ -701,32 +839,35 @@ TestRoleResponseTypeDef = TypedDict(
 ThumbnailsTypeDef = TypedDict(
     "ThumbnailsTypeDef",
     {
-        "Format": NotRequired[str],
-        "Interval": NotRequired[str],
-        "Resolution": NotRequired[str],
-        "AspectRatio": NotRequired[str],
-        "MaxWidth": NotRequired[str],
-        "MaxHeight": NotRequired[str],
-        "SizingPolicy": NotRequired[str],
-        "PaddingPolicy": NotRequired[str],
+        "Format": str,
+        "Interval": str,
+        "Resolution": str,
+        "AspectRatio": str,
+        "MaxWidth": str,
+        "MaxHeight": str,
+        "SizingPolicy": str,
+        "PaddingPolicy": str,
     },
+    total=False,
 )
 
 TimeSpanTypeDef = TypedDict(
     "TimeSpanTypeDef",
     {
-        "StartTime": NotRequired[str],
-        "Duration": NotRequired[str],
+        "StartTime": str,
+        "Duration": str,
     },
+    total=False,
 )
 
 TimingTypeDef = TypedDict(
     "TimingTypeDef",
     {
-        "SubmitTimeMillis": NotRequired[int],
-        "StartTimeMillis": NotRequired[int],
-        "FinishTimeMillis": NotRequired[int],
+        "SubmitTimeMillis": int,
+        "StartTimeMillis": int,
+        "FinishTimeMillis": int,
     },
+    total=False,
 )
 
 UpdatePipelineNotificationsRequestRequestTypeDef = TypedDict(
@@ -745,19 +886,32 @@ UpdatePipelineNotificationsResponseTypeDef = TypedDict(
     },
 )
 
-UpdatePipelineRequestRequestTypeDef = TypedDict(
-    "UpdatePipelineRequestRequestTypeDef",
+_RequiredUpdatePipelineRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePipelineRequestRequestTypeDef",
     {
         "Id": str,
-        "Name": NotRequired[str],
-        "InputBucket": NotRequired[str],
-        "Role": NotRequired[str],
-        "AwsKmsKeyArn": NotRequired[str],
-        "Notifications": NotRequired["NotificationsTypeDef"],
-        "ContentConfig": NotRequired["PipelineOutputConfigTypeDef"],
-        "ThumbnailConfig": NotRequired["PipelineOutputConfigTypeDef"],
     },
 )
+_OptionalUpdatePipelineRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePipelineRequestRequestTypeDef",
+    {
+        "Name": str,
+        "InputBucket": str,
+        "Role": str,
+        "AwsKmsKeyArn": str,
+        "Notifications": "NotificationsTypeDef",
+        "ContentConfig": "PipelineOutputConfigTypeDef",
+        "ThumbnailConfig": "PipelineOutputConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdatePipelineRequestRequestTypeDef(
+    _RequiredUpdatePipelineRequestRequestTypeDef, _OptionalUpdatePipelineRequestRequestTypeDef
+):
+    pass
+
 
 UpdatePipelineResponseTypeDef = TypedDict(
     "UpdatePipelineResponseTypeDef",
@@ -787,36 +941,39 @@ UpdatePipelineStatusResponseTypeDef = TypedDict(
 VideoParametersTypeDef = TypedDict(
     "VideoParametersTypeDef",
     {
-        "Codec": NotRequired[str],
-        "CodecOptions": NotRequired[Mapping[str, str]],
-        "KeyframesMaxDist": NotRequired[str],
-        "FixedGOP": NotRequired[str],
-        "BitRate": NotRequired[str],
-        "FrameRate": NotRequired[str],
-        "MaxFrameRate": NotRequired[str],
-        "Resolution": NotRequired[str],
-        "AspectRatio": NotRequired[str],
-        "MaxWidth": NotRequired[str],
-        "MaxHeight": NotRequired[str],
-        "DisplayAspectRatio": NotRequired[str],
-        "SizingPolicy": NotRequired[str],
-        "PaddingPolicy": NotRequired[str],
-        "Watermarks": NotRequired[Sequence["PresetWatermarkTypeDef"]],
+        "Codec": str,
+        "CodecOptions": Mapping[str, str],
+        "KeyframesMaxDist": str,
+        "FixedGOP": str,
+        "BitRate": str,
+        "FrameRate": str,
+        "MaxFrameRate": str,
+        "Resolution": str,
+        "AspectRatio": str,
+        "MaxWidth": str,
+        "MaxHeight": str,
+        "DisplayAspectRatio": str,
+        "SizingPolicy": str,
+        "PaddingPolicy": str,
+        "Watermarks": Sequence["PresetWatermarkTypeDef"],
     },
+    total=False,
 )
 
 WaiterConfigTypeDef = TypedDict(
     "WaiterConfigTypeDef",
     {
-        "Delay": NotRequired[int],
-        "MaxAttempts": NotRequired[int],
+        "Delay": int,
+        "MaxAttempts": int,
     },
+    total=False,
 )
 
 WarningTypeDef = TypedDict(
     "WarningTypeDef",
     {
-        "Code": NotRequired[str],
-        "Message": NotRequired[str],
+        "Code": str,
+        "Message": str,
     },
+    total=False,
 )
