@@ -1,7 +1,7 @@
 """
 Type annotations for elastictranscoder service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/)
 
 Usage::
 
@@ -29,11 +29,11 @@ __all__ = ("JobCompleteWaiter",)
 class JobCompleteWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/#jobcompletewaiter)
     """
 
-    def wait(self, *, Id: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
+    def wait(self, *, Id: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/#jobcompletewaiter)
         """
